<?php 

$config['registered_user_default_role_id'] = 3;

$config['registration_page'] = base_url('sign_up');
$config['forgot_password_page'] = base_url('forgotpassword');
$config['profile_page'] = base_url('profile');

$config['logged_in_redirect_page'] = '/';

$config['user_forms'] = [
    'register'    => 'user/forms/register_form',
    'profile'     => 'user/forms/profile_form',
    'change_pass' => 'user/forms/change_pass_form',
];
$config['form_error_delimeter_open'] = '<p class="error">';
$config['form_error_delimeter_close'] = '</p>';

$config['user_prepare_data'] = [
    'main_data'      => 'user/prepare_main_data',
    'translate_data' => 'user/prepare_translate_data',
];
