<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

// SplObserver libraries for model user_register_model
$config['user_events_user_register_model'] = [
    'user/events/send_confirm_email',
];

// SplObserver libraries for model user_model_site
$config['user_events_user_model_site'] = [
];
